@@ -22,6 +22,7 @@ from sklearn.metrics import mean_squared_error, r2_score
 from sklearn.feature_selection import f_regression, SequentialFeatureSelector
 from sklearn.preprocessing import PolynomialFeatures
 from sklearn.pipeline import make_pipeline
+from sklearn.neural_network import MLPRegressor
 
 # Import Scikit-Learn library for decision tree models
 import sklearn         
@@ -276,7 +277,8 @@ def rdf_online(eis_data,cycling_data,n_estimators, max_features, max_depth,test_
     X=np.transpose(X_features)
     y=np.transpose(ret)
     y=y[1:45]
-    
+    model = RandomForestRegressor(n_estimators= n_estimators, max_features = max_features, max_depth=max_depth,random_state=42,n_jobs=-1)
+      
     X_dev, X_test, y_dev, y_test = train_test_split(X, y, test_size= test_size, random_state=42)
     model.fit(X_dev, y_dev)
     
@@ -294,17 +296,17 @@ def rdf_online(eis_data,cycling_data,n_estimators, max_features, max_depth,test_
 
 def battery_clf(eis_data,cycling_data):
     Grade = {'98': 'AA', '97': 'A', '96': 'B+','95': 'B','94': 'C+','93': 'C'}
-    X_features=ml_input(eis_data,cycling_data)
-    rdf = joblib.load(filename)
-    nn  = joblib.load(filename)
-    gdb = joblib.load(filename)
+    X_features= ml_features(eis_data,cycling_data)
+    rdf = joblib.load(os.path.join(data_path,'rdf.sav'))
+    nn  = joblib.load(os.path.join(data_path,'MLP_NN_Optimized.sav'))
+    gdb = joblib.load(os.path.join(data_path,'gradient_boosting.sav'))
     rdf_pred=rdf.predict(X_features)
     nn_pred=nn.predict(X_features)
     gdb_pred=gdb.predict(X_features)
     average_error= 0.15
-    result = np.mean(rdf_pred[299],nn_pred[299],gdb_pred)
+    result = np.mean([rdf_pred[0][299],nn_pred[0][299],gdb_pred[0]])
     clf=str(math.floor(result-average_error))
-    return (Grade[clf])
+    return (Grade[clf],round(result,2),average_error)
 
 
 def gbr_online(eis_data,cycling_data,n_estimators, max_depth, learning_rate,test_size,cyc_num):
@@ -359,7 +361,7 @@ def MSE_per_cycle(y_pred, y_act):
         MSE_per_cycle.append(mean_squared_error(y_act.transpose()[i],y_pred.transpose()[i]))
     return MSE_per_cycle
 
-def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate, alpha, n_iter, test_size, random_state=None):
+def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate, alpha, n_iter, test_size,cyc_num,random_state=None):
     
     '''Online sklearn MLPRegressor NN for prediction of capacity at every cycle 1-300n
     
@@ -403,7 +405,6 @@ def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate,
     Z2max=loadtxt(os.path.join(data_path,'Z2max.csv'), delimiter=',')
     Z1min=loadtxt(os.path.join(data_path,'Z1min.csv'), delimiter=',')
     Z2min=loadtxt(os.path.join(data_path,'Z2min.csv'), delimiter=',')
-    f_min=loadtxt(os.path.join(data_path,'freq_fit_min.csv'), delimiter=',')
     f_max=loadtxt(os.path.join(data_path,'freq_fit_max.csv'), delimiter=',')
     Z1_hf=loadtxt(os.path.join(data_path,'Z1_high_f.csv'), delimiter=',')
     Z2_hf=loadtxt(os.path.join(data_path,'Z2_high_f.csv'), delimiter=',')               
@@ -421,7 +422,7 @@ def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate,
     
     #Predicting test data
     
-    y_pred_online = online_NN.predict(x_test)
+    y_pred_online = online_NN.predict(X_test)
     
     #Accuracy params for test data
     
@@ -433,13 +434,12 @@ def cap_ret_online_NN(eis_data,cycling_data, hidden_layers_sizes, learning_rate,
     
     cap_ret_pred = online_NN.predict(input_features)
     fig, ax = plt.subplots()
-    fig.text(0.45,0.8,'Model $R^{2}$ = '+str(round(r2,2)))
-    fig=plt.plot(cap_ret[0])
+    fig.text(0.45,0.8,'Model $R^{2}$ = '+str(round(r2_online_NN,2)))
+    fig=plt.plot(cap_ret_pred[0])
     plt.xlabel('Cycle Number')
     plt.ylabel('Capacity Retetion, [%]')
     avg_error=average_error(y_test,online_NN.predict(X_test))
-
-    return (fig,round(cap_ret[0][cyc_num-1],2),avg_error)
+    return (fig,round(cap_ret_pred[0][cyc_num-1],2),avg_error)
 
 def cap_ret_offline_NN(eis_data,cycling_data):
     '''Offline sklearn MLPRegressor NN for prediction of capacity at every cycle 1-300n
